@@ -1,44 +1,27 @@
-;;; klabel.el --- Display label handling for koutlines.
-
-;; Copyright (C) 2008 Free Software Foundation, Inc.
-;; Developed with support from Motorola Inc.
-
-;; Author: Bob Weiner, Brown U.
-;;         Kellie Clark
-;; Maintainer: Mats Lidell <matsl@contactor.se>
-;; Keywords: outlines, wp
-
+;;; klabel.el --- Display label handling for koutlines
+;;
+;; Author:       Bob Weiner
+;;
+;; Orig-Date:    17-Apr-94
+;;
+;; Copyright (C) 1994-2016  Free Software Foundation, Inc.
+;; See the "../HY-COPY" file for license information.
+;;
 ;; This file is part of GNU Hyperbole.
 
-;; GNU Hyperbole is free software; you can redistribute it and/or
-;; modify it under the terms of the GNU General Public License as
-;; published by the Free Software Foundation; either version 3, or (at
-;; your option) any later version.
-
-;; GNU Hyperbole is distributed in the hope that it will be useful,
-;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-;; General Public License for more details.
-
-;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-;; Boston, MA 02110-1301, USA.
-
 ;;; Commentary:
 
 ;;; Code:
-
-;;;
+;;; ************************************************************************
 ;;; Public variables
-;;;
+;;; ************************************************************************
 
 (defvar klabel-type:changing-flag nil
   "Non-nil only while the label type in the current view is being changed.")
 
-;;;
+;;; ************************************************************************
 ;;; Public functions
-;;;
+;;; ************************************************************************
 
 ;;;
 ;;; klabel - koutline display labels
@@ -48,10 +31,27 @@
   "Return LABEL's child cell label."
   (funcall (kview:get-attr kview 'label-child) label))
 
+(defun klabel:idstamp-p (label)
+  "Return t if LABEL is an idstamp label, else nil."
+  (cond ((stringp label)
+	 (if (string-match "\\`0[0-9]+\\'" label) t))
+	((integerp label)
+	 (>= label 0))))
+
 (defun klabel:increment (label)
   "Return LABEL's sibling label."
   (funcall (kview:get-attr kview 'label-increment) label))
 
+(defun klabel:format (label)
+  "Format a generic cell LABEL (a string) and return it in the proper display type for the current kview."
+  (let ((label-type (or (kview:get-attr kview 'label-type) kview:default-label-type)))
+    (cond ((memq label-type '(alpha id legal partial-alpha))
+	   label)
+	  ((eq label-type 'no) "")
+	  ((eq label-type 'star) "*")
+	  ((eq label-type 'id) label)
+	  (t (error "(klabel:format): Invalid label type setting: `%s'" label-type)))))
+
 (defun klabel:level (label)
   "Return outline level of LABEL using current kview label type."
   (let ((label-type (kview:label-type kview)))
@@ -61,63 +61,46 @@
 		    label))
 	  ((eq label-type 'no) 1)
 	  ((eq label-type 'star) (length label))
-	  ((eq label-type 'id)
-	   (error
-	    "(klabel:level): Can't compute the level of an idstamp label"))
-	  ((eq label-type 'partial-alpha)
-	   (error
-	    "(klabel:level): Can't compute the level of a partial-alpha label"))
-	  (t (error "(klabel:level): Invalid label type setting: '%s'"
+	  ((memq label-type '(id partial-alpha))
+	   (kcell-view:level))
+	  (t (error "(klabel:level): Invalid label type setting: `%s'"
 		    label-type)))))
 
 (defun klabel:parent (label)
   "Return LABEL's parent label."
   (funcall (kview:get-attr kview 'label-parent) label))
 
+;;;
+;;; klabel-type - kview-specific label type functions
+;;;
 (defun klabel-type:child (label-type)
   "Return function which computes child cell label of LABEL-TYPE."
   (cond ((memq label-type '(alpha legal partial-alpha))
 	 (intern-soft (concat "klabel:child-"
 			      (symbol-name label-type))))
 	((eq label-type 'no)
-	 (function (lambda (label) "")))
+	 (lambda (label) ""))
 	((eq label-type 'star)
-	 (function (lambda (label) (concat label "*"))))
+	 (lambda (label) (concat label "*")))
 	((eq label-type 'id)
-	 (function
-	  (lambda (label)
-	    (error
-	     "(klabel:child-id): Can't compute child of idstamp label"))))
+	 (lambda (label) (format "0%s" (or (kview:id-counter kview) ""))))
 	(t (error
-	    "(klabel-type:child): Invalid label type setting: '%s'"
+	    "(klabel-type:child): Invalid label type setting: `%s'"
 	    label-type))))
 
 (defun klabel-type:increment (label-type)
-  "Return function which computes sibling cell label of LABEL-TYPE."
+  "Return a function that takes a single label argument and computes the next cell label of LABEL-TYPE.
+If the label is \"0\", its first child is computed, otherwise, the next sibling is computed."
   (cond ((memq label-type '(alpha legal partial-alpha))
-	 (intern-soft (concat "klabel:increment-"
-			      (symbol-name label-type))))
+	 (intern-soft (concat "klabel:increment-" (symbol-name label-type))))
 	((eq label-type 'no)
-	 (function
-	  (lambda (label)
-	    (if (equal label "0")
-		(error "(klabel:increment-no): 0 cell cannot have a sibling")
-	      ""))))
+	 (lambda (label) ""))
 	((eq label-type 'star)
-	 (function
-	  (lambda (label)
-	    (if (string-equal label "0")
-		(error "(klabel:increment-star): 0 cell cannot have a sibling")
-	      label))))
+	 (lambda (label) (if (string-equal label "0") "*" label)))
 	((eq label-type 'id)
-	 (function
-	  (lambda (label)
-	    (if (string-equal label "0")
-		(error "(klabel:increment-no): 0 cell cannot have a sibling")
-	      (error "(klabel:increment-id): Can't compute sibling of idstamp label")))))
+	 (lambda (label) (format "0%s" (or (kview:id-increment kview) ""))))
 	(t (error
-	    "(klabel:increment): Invalid label type setting: '%s'"
-	    label-type))))
+	    "(klabel:increment): Invalid label type setting: `%s'" label-type))))
 
 (defun klabel-type:parent (label-type)
   "Return function which computes parent cell label of LABEL-TYPE."
@@ -125,29 +108,25 @@
 	 (intern-soft (concat "klabel:parent-"
 			      (symbol-name label-type))))
 	((eq label-type 'no)
-	 (function
-	  (lambda (label)
-	    (if (equal label "0")
-		(error "(klabel:parent-no): 0 cell cannot have a parent")
-	      ""))))
+	 (lambda (label)
+	   (if (equal label "0")
+	       (error "(klabel:parent-no): 0 cell cannot have a parent")
+	     "")))
 	((eq label-type 'star)
-	 (function
-	  (lambda (label)
-	    (if (string-equal label "0")
-		(error "(klabel:parent-star): 0 cell cannot have a parent")
-	      (substring label 0 (1- (length label)))))))
-	((eq label-type 'partial-alpha)
-	 (function
-	  (lambda (label)
-	    (error
-	     "(klabel:parent-partial-alpha): Can't compute parent of partial alpha label"))))
-	((eq label-type 'id)
-	 (function
-	  (lambda (label)
-	    (error
-	     "(klabel:parent-id): Can't compute parent of idstamp label"))))
+	 (lambda (label)
+	   (if (string-equal label "0")
+	       (error "(klabel:parent-star): 0 cell cannot have a parent")
+	     (substring label 0 (1- (length label))))))
+	((memq label-type '(id partial-alpha))
+	 (lambda (label)
+	   (if (string-equal label "0")
+	       (error "(klabel:increment-no): 0 cell cannot have a parent")
+	     (save-excursion
+	       (format "0%s" (if (eq (kcell-view:parent) 0)
+				 ""
+			       (kcell-view:label (point))))))))
 	(t (error
-	    "(klabel-type:parent): Invalid label type setting: '%s'"
+	    "(klabel-type:parent): Invalid label type setting: `%s'"
 	    label-type))))
 
 ;;;
@@ -165,7 +144,7 @@
 (defun klabel:increment-alpha (alpha-label)
   "Increment full ALPHA-LABEL by one and return."
   (if (string-equal alpha-label "0")
-      (error "(klabel:increment-alpha): 0 cell cannot have a sibling")
+      "1"
     (let ((kotl-label (klabel:to-kotl-label alpha-label)))
       (concat (substring alpha-label 0 (- (length kotl-label)))
 	      (kotl-label:increment kotl-label 1)))))
@@ -204,12 +183,12 @@ First visible outline cell is level 1."
 ;;; partial-alpha klabels
 ;;;
 
-(fset 'klabel:child-partial-alpha 'kotl-label:child)
+(defalias 'klabel:child-partial-alpha 'kotl-label:child)
 
 (defun klabel:increment-partial-alpha (label)
   "Increment partial alpha LABEL by one and return."
   (if (string-equal label "0")
-      (error "(klabel:increment-partial-alpha): 0 cell cannot have a sibling")
+      "1"
     (kotl-label:increment label 1)))
 
 ;;;
@@ -226,12 +205,12 @@ First visible outline cell is level 1."
 (defun klabel:increment-legal (label)
   "Increment full legal LABEL by one and return."
   (cond ((string-equal label "0")
-	 (error "(klabel:increment-legal): 0 cell cannot have a sibling"))
+	 "1")
 	((string-match "[0-9]+$" label)
 	 (concat (substring label 0 (match-beginning 0))
 		 (int-to-string
 		  (1+ (string-to-number (substring label (match-beginning 0)))))))
-	(t (error "(klabel:increment-legal): Invalid label, '%s'" label))))
+	(t (error "(klabel:increment-legal): Invalid label, `%s'" label))))
 
 (defun klabel:level-legal (label)
   "Return outline level as an integer of legal-style LABEL.
@@ -242,7 +221,7 @@ First visible outline cell is level 1."
 	  (level 1)
 	  (len (length label)))
       (while (< i len)
-	(if (= (aref label i) ?.)
+	(if (eq (aref label i) ?.)
 	    (setq level (1+ level)))
 	(setq i (1+ i)))
       level)))
@@ -261,12 +240,14 @@ First visible outline cell is level 1."
 ;;;
 ;; Default label-type to use for new views.
 ;; It must be one of the following symbols:
-;;   no              for no labels,
+;;   alpha           for `1a2' full alphanumeric labels
 ;;   id              for permanent idstamp labels, e.g. 001, 002, etc.
-;;   alpha           for '1a2' full alphanumeric labels
-;;   legal           for '1.1.2' labels
-;;   partial-alpha   for partial alphanumeric labels, e.g. '2' for node '1a2'
-;;   star            for multi-star labeling, e.g. '***'.
+;;   legal           for `1.1.2' labels
+;;
+;;   These are disable for now as more work is needed:
+;;     no              for no labels,
+;;     partial-alpha   for partial alphanumeric labels, e.g. `2' for node `1a2'
+;;     star            for multi-star labeling, e.g. `***'.
 
 ;;
 ;; Functions to compute sibling and child labels for particular label types.
@@ -280,17 +261,17 @@ is the display label of the cell preceding the current one and child-p is
 non-nil if cell is to be the child of the preceding cell."
   (or label-type (setq label-type (kview:label-type kview)))
   (cond ((eq label-type 'no)
-	 (function (lambda (prev-label &optional child-p)
-		     "")))
+	 (lambda (prev-label &optional child-p)
+	   ""))
 	((eq label-type 'partial-alpha)
-	 (function (lambda (prev-label &optional child-p)
-		     (if child-p
-			 (if (kotl-label:integer-p prev-label)
-			     "a" "1")
-		       (kotl-label:increment prev-label 1)))))
+	 (lambda (prev-label &optional child-p)
+	   (if child-p
+	       (if (kotl-label:integer-p prev-label)
+		   "a" "1")
+	     (kotl-label:increment prev-label 1))))
 	((eq label-type 'id)
-	 (function (lambda (prev-label &optional child-p)
-		     (format "0%d" (kcell-view:idstamp)))))
+	 (lambda (prev-label &optional child-p)
+	   (kcell-view:idstamp)))
 	(t (intern-soft (concat "klabel-type:"
 				(symbol-name label-type) "-label")))))
 
@@ -308,71 +289,12 @@ With optional CHILD-P, return label for first child cell of PREV-LABEL cell."
       (if (string-equal prev-label "0")
 	  "1"
 	(concat prev-label ".1"))
-    (let* ((last-part (string-match "[0-9]+$" prev-label))
-	   (partial-legal (substring prev-label last-part))
-	   (next (kotl-label:create (1+ (string-to-number partial-legal)))))
+    (let* ((last-part-index (string-match "[0-9]+$" prev-label))
+	   (last-part (substring prev-label last-part-index))
+	   (next-last-part (kotl-label:create (1+ (string-to-number last-part)))))
       (if (equal last-part prev-label)
-	  next
-	(concat (substring prev-label 0 last-part) next)))))
-
-(defun klabel-type:to-label-end (&optional label-type)
-  "Return function which will search backward to a the end of a cell's label.
-Label format is optional LABEL-TYPE or the default label type for the current view.
-
-Function signature is: ().  It takes no arguments and begins the search from point."
-  (or label-type (setq label-type (kview:label-type kview)))
-  (or (cdr (assq label-type
-		 (list
-		  (cons
-		   'alpha
-		   (function
-		    (lambda ()
-		      (if (re-search-backward
-			   "\\(\\`\\|[\n\r][\n\r]\\)[ \t]*[1-9][0-9a-zA-Z]*"
-			   nil t)
-			  (goto-char (match-end 0))))))
-		  (cons
-		   'legal
-		   (function
-		    (lambda ()
-		      (if (re-search-backward
-			   "\\(\\`\\|[\n\r][\n\r]\\)[ \t]*[0-9]+\\(\\.[0-9]+\\)*"
-			   nil t)
-			  (goto-char (match-end 0))))))
-		    (cons
-		     'star
-		     (function
-		      (lambda ()
-			(if (re-search-backward
-			     "\\(\\`\\|[\n\r][\n\r]\\)[ \t]*\\*+" nil t)
-			    (goto-char (match-end 0))))))
-		    (cons
-		     'no
-		     (function
-		      (lambda ()
-			(goto-char
-			 (if (and (not hyperb:xemacs-p)
-				  (string-lessp emacs-version "19.22"))
-			     (kproperty:previous-single-change (point) 'kcell)
-			   ;; (GNU Emacs V19.22 / Lucid Emacs V19.9) or greater
-			   (- (kproperty:previous-single-change
-			       (point) 'kcell) 1))))))
-		    (cons
-		     'partial-alpha
-		     (function
-		      (lambda ()
-			(if (re-search-backward
-			     "\\(\\`\\|[\n\r][\n\r]\\)[ \t]*[0-9]+\\|[a-zA-Z]+"
-			     nil t)
-			    (goto-char (match-end 0))))))
-		    (cons
-		     'id
-		     (function
-		      (lambda ()
-			(if (re-search-backward
-			     "\\(\\`\\|[\n\r][\n\r]\\)[ \t]*0[0-9]+" nil t)
-			    (goto-char (match-end 0)))))))))
-	(error "(kview:to-label-end): Invalid label type: '%s'" label-type)))
+	  next-last-part
+	(concat (substring prev-label 0 last-part-index) next-last-part)))))
 
 (defun klabel-type:star-label (prev-label &optional child-p)
   "Return full star label, e.g. ***, for cell following PREV-LABEL's cell.
@@ -399,7 +321,7 @@ With optional CHILD-P, return label for first child cell of PREV-LABEL cell."
 		  ((eq label-type 'no) "")
 		  ((eq label-type 'star) "*")
 		  (t (error
-		      "(klabel-type:set-labels): Invalid label type: '%s'"
+		      "(klabel-type:set-labels): Invalid label type: `%s'"
 		      label-type))))
       (let ((klabel-type:changing-flag t))
 	(klabel-type:update-labels-from-point label-type first-label)))))
@@ -552,21 +474,22 @@ and the start of its contents."
 		  (kcell-view:next nil label-sep-len)))))
 
 (defun klabel-type:update-labels (current-cell-label)
-  "Update the labels of current cell, its following siblings and their subtrees.
+  "Update the labels of current cell, its following siblings and their subtrees if need be.
 CURRENT-CELL-LABEL is the label to display for the current cell.
 If, however, it is \"0\", then all cell labels are updated."
   (let ((label-type (kview:label-type kview)))
-    (if (string-equal current-cell-label "0")
-	;; Update all cells in view.
-	(klabel-type:set-labels label-type)
-      ;; Update current tree and its siblings only.
-      (klabel-type:update-labels-from-point
-       label-type current-cell-label))))
+    (if (memq label-type '(alpha legal partial-alpha))
+	(if (string-equal current-cell-label "0")
+	    ;; Update all cells in view.
+	    (klabel-type:set-labels label-type)
+	  ;; Update current tree and its siblings only.
+	  (klabel-type:update-labels-from-point
+	   label-type current-cell-label)))))
 
-(defun klabel-type:update-tree-labels (current-cell-label)
+(defun klabel-type:update-tree-labels (current-cell-label first-label)
   "Update the labels of current cell and its subtree.
 CURRENT-CELL-LABEL is the label to display for the current cell.
-Use '(klabel-type:update-labels "0")' to update all cells in an outline."
+Use `(klabel-type:update-labels "0")' to update all cells in an outline."
   (let ((label-type (kview:label-type kview))
 	(label-sep-len (kview:label-separator-length kview)))
     (save-excursion
@@ -579,22 +502,19 @@ Use '(klabel-type:update-labels "0")' to update all cells in an outline."
 	       t))))
 
 ;;;
-;;; kotl-label--the part of a full label which represents a
-;;;             kcell's relative position in the koutline hierarchy,
+;;; kotl-label--the rightmost (deepest level) part of a full label,
 ;;;             e.g. the full label "1a2" has kotl-label "2".
 ;;;
 (defun kotl-label:alpha-to-int (alpha-label)
   "Return integer value of ALPHA-LABEL, e.g. `b' returns 2.
-Assumes ALPHA-LABEL is alphabetic."
+Assumes ALPHA-LABEL is alphabetic and lowercase."
   (let ((power (length alpha-label))
 	(digit 0)
 	(min (1- ?a)))
-    (apply '+ (mapcar
-	       (function (lambda (chr)
-			   (setq digit (- chr min)
-				 power (1- power))
-			   (* (apply '* (make-list power 26)) digit)
-			   ))
+    (apply '+ (mapcar (lambda (chr)
+			(setq digit (- chr min)
+			      power (1- power))
+			(* digit (expt 26 power)))
 	       alpha-label))))
 
 (defun kotl-label:alpha-p (label)
@@ -618,12 +538,12 @@ Assumes ALPHA-LABEL is alphabetic."
 (defun kotl-label:increment (label n)
   "Return LABEL incremented by N.
 For example, if N were 1, 2 would become 3, z would become aa, and aa would
-become bb.  If N were -2, 4 would become 2, etc.
+become ab.  If N were -2, 4 would become 2, etc.
 LABEL must be >= 1 or >= a.  If LABEL is decremented below 1 or a, an error
 is signaled."
   (if (not (kotl-label:is-p label))
       (error
-       "(kotl-label:increment): First arg, '%s', must be a kotl-label."
+       "(kotl-label:increment): First arg, `%s', must be a kotl-label."
        label))
   (let ((int-p) (val 0))
     (if (or (setq int-p (kotl-label:integer-p label))
@@ -633,19 +553,17 @@ is signaled."
 	    (progn (setq int-p (string-to-number label))
 		   (if (> (setq val (+ int-p n)) 0)
 		       (kotl-label:create val)
-		     (error "(kotl-label:increment): Decrement of '%s' by '%d' is less than 1." label n)))
+		     (error "(kotl-label:increment): Decrement of `%s' by `%d' is less than 1." label n)))
 	  ;; alpha-p
 	  (if (<= 0 (setq val (+ n (kotl-label:alpha-to-int label))))
-	      (kotl-label:create
-	       (kotl-label:int-to-alpha val))
-	    (error "(kotl-label:increment): Decrement of '%s' by '%d' is illegal." label n)))
-      (error "(kotl-label:increment): label, '%s', must be all digits or alpha characters" label))))
+	      (kotl-label:create (kotl-label:int-to-alpha val))
+	    (error "(kotl-label:increment): Decrement of `%s' by `%d' is illegal." label n)))
+      (error "(kotl-label:increment): label, `%s', must be all digits or alpha characters" label))))
 
 (defun kotl-label:increment-alpha (label)
   "Return alphabetic LABEL incremented by 1.
 For example, z would become aa, and aa would become bb.  LABEL must be >= a." 
-  (kotl-label:int-to-alpha
-   (1+ (kotl-label:alpha-to-int label))))
+  (kotl-label:int-to-alpha (1+ (kotl-label:alpha-to-int label))))
 
 (defun kotl-label:increment-int (int-string)
   "Return INT-STRING label incremented by 1.
@@ -667,8 +585,8 @@ N may be an integer or a string containing an integer."
   (let ((lbl "") pow26 exp26 quotient remainder)
     (if (= n 0)
 	""
-      (setq pow26 (floor (kotl-label:log26
-			  (if (= (mod (1- n) 26) 0) n (1- n)))))
+      (setq pow26 (floor (log (if (= (mod (1- n) 26) 0) n (1- n))
+			      26)))
       (while (>= pow26 0)
 	(setq exp26 (expt 26 pow26)
 	      quotient (floor (/ n exp26))
@@ -688,9 +606,9 @@ N may be an integer or a string containing an integer."
 
 
 
-;;;
+;;; ************************************************************************
 ;;; Private functions
-;;;
+;;; ************************************************************************
 
 (defun klabel:set (new-label &optional label-sep-len)
   "Replace label displayed in cell at point with NEW-LABEL, which may be a different label type.
@@ -703,7 +621,7 @@ Return NEW-LABEL string."
     (save-excursion
       (kcell-view:to-label-end)
       ;; delete backwards thru label
-      (delete-backward-char thru-label)
+      (delete-char (- thru-label))
       ;; replace with new label, right justified
       (insert (format (format "%%%ds" thru-label) new-label)))
     (set-buffer-modified-p modified)
@@ -714,7 +632,7 @@ Return NEW-LABEL string."
 For example, the full label \"1a2\" has kotl-label \"2\", as does \"1.1.2\"."
   (if (string-match "[0-9]+$\\|[a-zA-Z]+$" label)
       (substring label (match-beginning 0))
-    (error "(klabel:to-kotl-label): Invalid label, '%s'" label)))
+    (error "(klabel:to-kotl-label): Invalid label, `%s'" label)))
 
 (defun klabel-type:update-labels-from-point (label-type first-label)
   (let ((label-sep-len (kview:label-separator-length kview)))
@@ -725,12 +643,6 @@ For example, the full label \"1a2\" has kotl-label \"2\", as does \"1.1.2\"."
 	       (kcell-view:indent nil label-sep-len)
 	       (kview:level-indent kview)))))
 
-(defun kotl-label:log26 (n)
-  "Return log base 26 of integer N."
-  (/ (log10 n)
-     ;; Next line = (log10 26.514147167125703)
-     1.423477662509912))
-
 (provide 'klabel)
 
 ;;; klabel.el ends here
